# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class Zone(pulumi.CustomResource):
    additional_primaries: pulumi.Output[list]
    """
    List of additional IPv4 addresses for the primary
    zone. Conflicts with `secondaries`.
    """
    autogenerate_ns_record: pulumi.Output[bool]
    dns_servers: pulumi.Output[str]
    """
    (Computed) Authoritative Name Servers.
    """
    dnssec: pulumi.Output[bool]
    """
    Whether or not DNSSEC is enabled for the zone.
    Note that DNSSEC must be enabled on the account by support for this to be set
    to `true`.
    """
    expiry: pulumi.Output[float]
    """
    The SOA Expiry. Conflicts with `primary` and
    `additional_primaries` (default must be accepted).
    """
    hostmaster: pulumi.Output[str]
    """
    (Computed) The SOA Hostmaster.
    """
    link: pulumi.Output[str]
    """
    The target zone(domain name) to link to.
    """
    networks: pulumi.Output[list]
    """
    - List of network IDs (`int`) for which the zone
    should be made available. Default is network 0, the primary NSONE Global
    Network. Normally, you should not have to worry about this.
    """
    nx_ttl: pulumi.Output[float]
    """
    The SOA NX TTL. Conflicts with `primary` and
    `additional_primaries` (default must be accepted).
    """
    primary: pulumi.Output[str]
    """
    The primary zones' IPv4 address. This makes the zone a
    secondary. Conflicts with `secondaries`.
    """
    refresh: pulumi.Output[float]
    """
    The SOA Refresh. Conflicts with `primary` and
    `additional_primaries` (default must be accepted).
    """
    retry: pulumi.Output[float]
    """
    The SOA Retry. Conflicts with `primary` and
    `additional_primaries` (default must be accepted).
    """
    secondaries: pulumi.Output[list]
    """
    List of secondary servers. This makes the zone a
    primary. Conflicts with `primary` and `additional_primaries`.
    Secondaries is documented below.

      * `ip` (`str`) - IPv4 address of the secondary server.
      * `networks` (`list`) - - List of network IDs (`int`) for which the zone
        should be made available. Default is network 0, the primary NSONE Global
        Network. Normally, you should not have to worry about this.
      * `notify` (`bool`) - Whether we send `NOTIFY` messages to the secondary host
        when the zone changes. Default `false`.
      * `port` (`float`) - Port of the the secondary server. Default `53`.
    """
    ttl: pulumi.Output[float]
    """
    The SOA TTL.
    """
    zone: pulumi.Output[str]
    """
    The domain name of the zone.
    """
    def __init__(__self__, resource_name, opts=None, additional_primaries=None, autogenerate_ns_record=None, dnssec=None, expiry=None, link=None, networks=None, nx_ttl=None, primary=None, refresh=None, retry=None, secondaries=None, ttl=None, zone=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a Zone resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] additional_primaries: List of additional IPv4 addresses for the primary
               zone. Conflicts with `secondaries`.
        :param pulumi.Input[bool] dnssec: Whether or not DNSSEC is enabled for the zone.
               Note that DNSSEC must be enabled on the account by support for this to be set
               to `true`.
        :param pulumi.Input[float] expiry: The SOA Expiry. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[str] link: The target zone(domain name) to link to.
        :param pulumi.Input[list] networks: - List of network IDs (`int`) for which the zone
               should be made available. Default is network 0, the primary NSONE Global
               Network. Normally, you should not have to worry about this.
        :param pulumi.Input[float] nx_ttl: The SOA NX TTL. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[str] primary: The primary zones' IPv4 address. This makes the zone a
               secondary. Conflicts with `secondaries`.
        :param pulumi.Input[float] refresh: The SOA Refresh. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[float] retry: The SOA Retry. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[list] secondaries: List of secondary servers. This makes the zone a
               primary. Conflicts with `primary` and `additional_primaries`.
               Secondaries is documented below.
        :param pulumi.Input[float] ttl: The SOA TTL.
        :param pulumi.Input[str] zone: The domain name of the zone.

        The **secondaries** object supports the following:

          * `ip` (`pulumi.Input[str]`) - IPv4 address of the secondary server.
          * `networks` (`pulumi.Input[list]`) - - List of network IDs (`int`) for which the zone
            should be made available. Default is network 0, the primary NSONE Global
            Network. Normally, you should not have to worry about this.
          * `notify` (`pulumi.Input[bool]`) - Whether we send `NOTIFY` messages to the secondary host
            when the zone changes. Default `false`.
          * `port` (`pulumi.Input[float]`) - Port of the the secondary server. Default `53`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['additional_primaries'] = additional_primaries
            __props__['autogenerate_ns_record'] = autogenerate_ns_record
            __props__['dnssec'] = dnssec
            __props__['expiry'] = expiry
            __props__['link'] = link
            __props__['networks'] = networks
            __props__['nx_ttl'] = nx_ttl
            __props__['primary'] = primary
            __props__['refresh'] = refresh
            __props__['retry'] = retry
            __props__['secondaries'] = secondaries
            __props__['ttl'] = ttl
            if zone is None:
                raise TypeError("Missing required property 'zone'")
            __props__['zone'] = zone
            __props__['dns_servers'] = None
            __props__['hostmaster'] = None
        super(Zone, __self__).__init__(
            'ns1:index/zone:Zone',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, additional_primaries=None, autogenerate_ns_record=None, dns_servers=None, dnssec=None, expiry=None, hostmaster=None, link=None, networks=None, nx_ttl=None, primary=None, refresh=None, retry=None, secondaries=None, ttl=None, zone=None):
        """
        Get an existing Zone resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] additional_primaries: List of additional IPv4 addresses for the primary
               zone. Conflicts with `secondaries`.
        :param pulumi.Input[str] dns_servers: (Computed) Authoritative Name Servers.
        :param pulumi.Input[bool] dnssec: Whether or not DNSSEC is enabled for the zone.
               Note that DNSSEC must be enabled on the account by support for this to be set
               to `true`.
        :param pulumi.Input[float] expiry: The SOA Expiry. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[str] hostmaster: (Computed) The SOA Hostmaster.
        :param pulumi.Input[str] link: The target zone(domain name) to link to.
        :param pulumi.Input[list] networks: - List of network IDs (`int`) for which the zone
               should be made available. Default is network 0, the primary NSONE Global
               Network. Normally, you should not have to worry about this.
        :param pulumi.Input[float] nx_ttl: The SOA NX TTL. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[str] primary: The primary zones' IPv4 address. This makes the zone a
               secondary. Conflicts with `secondaries`.
        :param pulumi.Input[float] refresh: The SOA Refresh. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[float] retry: The SOA Retry. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[list] secondaries: List of secondary servers. This makes the zone a
               primary. Conflicts with `primary` and `additional_primaries`.
               Secondaries is documented below.
        :param pulumi.Input[float] ttl: The SOA TTL.
        :param pulumi.Input[str] zone: The domain name of the zone.

        The **secondaries** object supports the following:

          * `ip` (`pulumi.Input[str]`) - IPv4 address of the secondary server.
          * `networks` (`pulumi.Input[list]`) - - List of network IDs (`int`) for which the zone
            should be made available. Default is network 0, the primary NSONE Global
            Network. Normally, you should not have to worry about this.
          * `notify` (`pulumi.Input[bool]`) - Whether we send `NOTIFY` messages to the secondary host
            when the zone changes. Default `false`.
          * `port` (`pulumi.Input[float]`) - Port of the the secondary server. Default `53`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["additional_primaries"] = additional_primaries
        __props__["autogenerate_ns_record"] = autogenerate_ns_record
        __props__["dns_servers"] = dns_servers
        __props__["dnssec"] = dnssec
        __props__["expiry"] = expiry
        __props__["hostmaster"] = hostmaster
        __props__["link"] = link
        __props__["networks"] = networks
        __props__["nx_ttl"] = nx_ttl
        __props__["primary"] = primary
        __props__["refresh"] = refresh
        __props__["retry"] = retry
        __props__["secondaries"] = secondaries
        __props__["ttl"] = ttl
        __props__["zone"] = zone
        return Zone(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

__config__ = pulumi.Config('ns1')

apikey = __config__.get('apikey') or utilities.get_env('NS1_APIKEY')
"""
The ns1 API key, this is required
"""

enable_ddi = __config__.get('enableDdi')

endpoint = __config__.get('endpoint') or utilities.get_env('NS1_ENDPOINT')

ignore_ssl = __config__.get('ignoreSsl')

rate_limit_parallelism = __config__.get('rateLimitParallelism')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class Record(pulumi.CustomResource):
    answers: pulumi.Output[list]
    """
    One or more NS1 answers for the records' specified type.
    Answers are documented below.

      * `answer` (`str`) - Space delimited string of RDATA fields dependent on the record type.
      * `meta` (`dict`)
      * `region` (`str`) - The region (Answer Group really) that this answer
        belongs to. This should be one of the names specified in `regions`. Only a
        single `region` per answer is currently supported. If you want an answer in
        multiple regions, duplicating the answer (including metadata) is the correct
        approach.
        * ` meta` - (Optional) meta is supported at the `answer` level. Meta
        is documented below.
    """
    domain: pulumi.Output[str]
    """
    The records' domain. Cannot have leading or trailing
    dots - see the example above and `FQDN formatting` below.
    """
    filters: pulumi.Output[list]
    """
    One or more NS1 filters for the record(order matters).
    Filters are documented below.

      * `config` (`dict`) - The filters' configuration. Simple key/value pairs
        determined by the filter type.
      * `disabled` (`bool`) - Determines whether the filter is applied in the
        filter chain.
      * `filter` (`str`) - The type of filter.
    """
    link: pulumi.Output[str]
    """
    The target record to link to. This means this record is a
    'linked' record, and it inherits all properties from its target.
    """
    meta: pulumi.Output[dict]
    regions: pulumi.Output[list]
    """
    One or more "regions" for the record. These are really
    just groupings based on metadata, and are called "Answer Groups" in the NS1 UI,
    but remain `regions` here for legacy reasons. Regions are
    documented below. Please note the ordering requirement!

      * `meta` (`dict`)
      * `name` (`str`) - Name of the region (or Answer Group).
    """
    short_answers: pulumi.Output[list]
    ttl: pulumi.Output[float]
    """
    The records' time to live.
    """
    type: pulumi.Output[str]
    """
    The records' RR type.
    """
    use_client_subnet: pulumi.Output[bool]
    """
    Whether to use EDNS client subnet data when
    available(in filter chain).
    * ` meta` - (Optional) meta is supported at the `record` level. Meta
    is documented below.
    """
    zone: pulumi.Output[str]
    """
    The zone the record belongs to. Cannot have leading or
    trailing dots (".") - see the example above and `FQDN formatting` below.
    """
    def __init__(__self__, resource_name, opts=None, answers=None, domain=None, filters=None, link=None, meta=None, regions=None, short_answers=None, ttl=None, type=None, use_client_subnet=None, zone=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a NS1 Record resource. This can be used to create, modify, and delete records.

        ## NS1 Documentation

        [Record Api Doc](https://ns1.com/api#records)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] answers: One or more NS1 answers for the records' specified type.
               Answers are documented below.
        :param pulumi.Input[str] domain: The records' domain. Cannot have leading or trailing
               dots - see the example above and `FQDN formatting` below.
        :param pulumi.Input[list] filters: One or more NS1 filters for the record(order matters).
               Filters are documented below.
        :param pulumi.Input[str] link: The target record to link to. This means this record is a
               'linked' record, and it inherits all properties from its target.
        :param pulumi.Input[list] regions: One or more "regions" for the record. These are really
               just groupings based on metadata, and are called "Answer Groups" in the NS1 UI,
               but remain `regions` here for legacy reasons. Regions are
               documented below. Please note the ordering requirement!
        :param pulumi.Input[float] ttl: The records' time to live.
        :param pulumi.Input[str] type: The records' RR type.
        :param pulumi.Input[bool] use_client_subnet: Whether to use EDNS client subnet data when
               available(in filter chain).
               * ` meta` - (Optional) meta is supported at the `record` level. Meta
               is documented below.
        :param pulumi.Input[str] zone: The zone the record belongs to. Cannot have leading or
               trailing dots (".") - see the example above and `FQDN formatting` below.

        The **answers** object supports the following:

          * `answer` (`pulumi.Input[str]`) - Space delimited string of RDATA fields dependent on the record type.
          * `meta` (`pulumi.Input[dict]`)
          * `region` (`pulumi.Input[str]`) - The region (Answer Group really) that this answer
            belongs to. This should be one of the names specified in `regions`. Only a
            single `region` per answer is currently supported. If you want an answer in
            multiple regions, duplicating the answer (including metadata) is the correct
            approach.
            * ` meta` - (Optional) meta is supported at the `answer` level. Meta
            is documented below.

        The **filters** object supports the following:

          * `config` (`pulumi.Input[dict]`) - The filters' configuration. Simple key/value pairs
            determined by the filter type.
          * `disabled` (`pulumi.Input[bool]`) - Determines whether the filter is applied in the
            filter chain.
          * `filter` (`pulumi.Input[str]`) - The type of filter.

        The **regions** object supports the following:

          * `meta` (`pulumi.Input[dict]`)
          * `name` (`pulumi.Input[str]`) - Name of the region (or Answer Group).
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['answers'] = answers
            if domain is None:
                raise TypeError("Missing required property 'domain'")
            __props__['domain'] = domain
            __props__['filters'] = filters
            __props__['link'] = link
            __props__['meta'] = meta
            __props__['regions'] = regions
            if short_answers is not None:
                warnings.warn("short_answers will be deprecated in a future release. It is suggested to migrate to a regular \"answers\" block.", DeprecationWarning)
                pulumi.log.warn("short_answers is deprecated: short_answers will be deprecated in a future release. It is suggested to migrate to a regular \"answers\" block.")
            __props__['short_answers'] = short_answers
            __props__['ttl'] = ttl
            if type is None:
                raise TypeError("Missing required property 'type'")
            __props__['type'] = type
            __props__['use_client_subnet'] = use_client_subnet
            if zone is None:
                raise TypeError("Missing required property 'zone'")
            __props__['zone'] = zone
        super(Record, __self__).__init__(
            'ns1:index/record:Record',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, answers=None, domain=None, filters=None, link=None, meta=None, regions=None, short_answers=None, ttl=None, type=None, use_client_subnet=None, zone=None):
        """
        Get an existing Record resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] answers: One or more NS1 answers for the records' specified type.
               Answers are documented below.
        :param pulumi.Input[str] domain: The records' domain. Cannot have leading or trailing
               dots - see the example above and `FQDN formatting` below.
        :param pulumi.Input[list] filters: One or more NS1 filters for the record(order matters).
               Filters are documented below.
        :param pulumi.Input[str] link: The target record to link to. This means this record is a
               'linked' record, and it inherits all properties from its target.
        :param pulumi.Input[list] regions: One or more "regions" for the record. These are really
               just groupings based on metadata, and are called "Answer Groups" in the NS1 UI,
               but remain `regions` here for legacy reasons. Regions are
               documented below. Please note the ordering requirement!
        :param pulumi.Input[float] ttl: The records' time to live.
        :param pulumi.Input[str] type: The records' RR type.
        :param pulumi.Input[bool] use_client_subnet: Whether to use EDNS client subnet data when
               available(in filter chain).
               * ` meta` - (Optional) meta is supported at the `record` level. Meta
               is documented below.
        :param pulumi.Input[str] zone: The zone the record belongs to. Cannot have leading or
               trailing dots (".") - see the example above and `FQDN formatting` below.

        The **answers** object supports the following:

          * `answer` (`pulumi.Input[str]`) - Space delimited string of RDATA fields dependent on the record type.
          * `meta` (`pulumi.Input[dict]`)
          * `region` (`pulumi.Input[str]`) - The region (Answer Group really) that this answer
            belongs to. This should be one of the names specified in `regions`. Only a
            single `region` per answer is currently supported. If you want an answer in
            multiple regions, duplicating the answer (including metadata) is the correct
            approach.
            * ` meta` - (Optional) meta is supported at the `answer` level. Meta
            is documented below.

        The **filters** object supports the following:

          * `config` (`pulumi.Input[dict]`) - The filters' configuration. Simple key/value pairs
            determined by the filter type.
          * `disabled` (`pulumi.Input[bool]`) - Determines whether the filter is applied in the
            filter chain.
          * `filter` (`pulumi.Input[str]`) - The type of filter.

        The **regions** object supports the following:

          * `meta` (`pulumi.Input[dict]`)
          * `name` (`pulumi.Input[str]`) - Name of the region (or Answer Group).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["answers"] = answers
        __props__["domain"] = domain
        __props__["filters"] = filters
        __props__["link"] = link
        __props__["meta"] = meta
        __props__["regions"] = regions
        __props__["short_answers"] = short_answers
        __props__["ttl"] = ttl
        __props__["type"] = type
        __props__["use_client_subnet"] = use_client_subnet
        __props__["zone"] = zone
        return Record(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .api_key import *
from .data_feed import *
from .data_source import *
from .get_dns_sec import *
from .get_zone import *
from .monitoring_job import *
from .notify_list import *
from .provider import *
from .record import *
from .team import *
from .user import *
from .zone import *



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class MonitoringJob(pulumi.CustomResource):
    active: pulumi.Output[bool]
    """
    Indicates if the job is active or temporarily disabled.
    """
    config: pulumi.Output[dict]
    """
    A configuration dictionary with keys and values depending on the jobs' type.
    """
    frequency: pulumi.Output[float]
    """
    The frequency, in seconds, at which to run the monitoring job in each region.
    """
    job_type: pulumi.Output[str]
    """
    The type of monitoring job to be run. See NS1 API
    docs for supported values.
    """
    name: pulumi.Output[str]
    """
    The free-form display name for the monitoring job.
    """
    notes: pulumi.Output[str]
    """
    Freeform notes to be included in any notifications about this job.
    """
    notify_delay: pulumi.Output[float]
    """
    The time in seconds after a failure to wait before sending a notification.
    """
    notify_failback: pulumi.Output[bool]
    """
    If true, a notification is sent when a job returns to an "up" state.
    """
    notify_list: pulumi.Output[str]
    """
    The id of the notification list to send notifications to.
    """
    notify_regional: pulumi.Output[bool]
    """
    If true, notifications are sent for any regional failure (and failback if desired), in addition to global state notifications.
    """
    notify_repeat: pulumi.Output[float]
    """
    The time in seconds between repeat notifications of a failed job.
    """
    policy: pulumi.Output[str]
    """
    The policy for determining the monitor's global status
    based on the status of the job in all regions. See NS1 API docs for supported values.
    """
    rapid_recheck: pulumi.Output[bool]
    """
    If true, on any apparent state change, the job is quickly re-run after one second to confirm the state change before notification.
    """
    regions: pulumi.Output[list]
    """
    The list of region codes in which to run the monitoring
    job. See NS1 API docs for supported values.
    """
    rules: pulumi.Output[list]
    """
    A list of rules for determining failure conditions. Job Rules are documented below.

      * `comparison` (`str`) - The comparison to perform on the the output.
      * `key` (`str`) - The output key.
      * `value` (`str`) - The value to compare to.
    """
    def __init__(__self__, resource_name, opts=None, active=None, config=None, frequency=None, job_type=None, name=None, notes=None, notify_delay=None, notify_failback=None, notify_list=None, notify_regional=None, notify_repeat=None, policy=None, rapid_recheck=None, regions=None, rules=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a NS1 Monitoring Job resource. This can be used to create, modify, and delete monitoring jobs.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ns1 as ns1

        uswest_monitor = ns1.MonitoringJob("uswestMonitor",
            active=True,
            config={
                "host": "example-elb-uswest.aws.amazon.com",
                "port": 443,
                "send": \"\"\"HEAD / HTTP/1.0
        

        \"\"\",
                "ssl": 1,
            },
            frequency=60,
            job_type="tcp",
            policy="quorum",
            rapid_recheck=True,
            regions=[
                "sjc",
                "sin",
                "lga",
            ],
            rules=[{
                "comparison": "contains",
                "key": "output",
                "value": "200 OK",
            }])
        ```
        ## NS1 Documentation

        [MonitoringJob Api Doc](https://ns1.com/api#monitoring-jobs)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Indicates if the job is active or temporarily disabled.
        :param pulumi.Input[dict] config: A configuration dictionary with keys and values depending on the jobs' type.
        :param pulumi.Input[float] frequency: The frequency, in seconds, at which to run the monitoring job in each region.
        :param pulumi.Input[str] job_type: The type of monitoring job to be run. See NS1 API
               docs for supported values.
        :param pulumi.Input[str] name: The free-form display name for the monitoring job.
        :param pulumi.Input[str] notes: Freeform notes to be included in any notifications about this job.
        :param pulumi.Input[float] notify_delay: The time in seconds after a failure to wait before sending a notification.
        :param pulumi.Input[bool] notify_failback: If true, a notification is sent when a job returns to an "up" state.
        :param pulumi.Input[str] notify_list: The id of the notification list to send notifications to.
        :param pulumi.Input[bool] notify_regional: If true, notifications are sent for any regional failure (and failback if desired), in addition to global state notifications.
        :param pulumi.Input[float] notify_repeat: The time in seconds between repeat notifications of a failed job.
        :param pulumi.Input[str] policy: The policy for determining the monitor's global status
               based on the status of the job in all regions. See NS1 API docs for supported values.
        :param pulumi.Input[bool] rapid_recheck: If true, on any apparent state change, the job is quickly re-run after one second to confirm the state change before notification.
        :param pulumi.Input[list] regions: The list of region codes in which to run the monitoring
               job. See NS1 API docs for supported values.
        :param pulumi.Input[list] rules: A list of rules for determining failure conditions. Job Rules are documented below.

        The **rules** object supports the following:

          * `comparison` (`pulumi.Input[str]`) - The comparison to perform on the the output.
          * `key` (`pulumi.Input[str]`) - The output key.
          * `value` (`pulumi.Input[str]`) - The value to compare to.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['active'] = active
            if config is None:
                raise TypeError("Missing required property 'config'")
            __props__['config'] = config
            if frequency is None:
                raise TypeError("Missing required property 'frequency'")
            __props__['frequency'] = frequency
            if job_type is None:
                raise TypeError("Missing required property 'job_type'")
            __props__['job_type'] = job_type
            __props__['name'] = name
            __props__['notes'] = notes
            __props__['notify_delay'] = notify_delay
            __props__['notify_failback'] = notify_failback
            __props__['notify_list'] = notify_list
            __props__['notify_regional'] = notify_regional
            __props__['notify_repeat'] = notify_repeat
            __props__['policy'] = policy
            __props__['rapid_recheck'] = rapid_recheck
            if regions is None:
                raise TypeError("Missing required property 'regions'")
            __props__['regions'] = regions
            __props__['rules'] = rules
        super(MonitoringJob, __self__).__init__(
            'ns1:index/monitoringJob:MonitoringJob',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, active=None, config=None, frequency=None, job_type=None, name=None, notes=None, notify_delay=None, notify_failback=None, notify_list=None, notify_regional=None, notify_repeat=None, policy=None, rapid_recheck=None, regions=None, rules=None):
        """
        Get an existing MonitoringJob resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Indicates if the job is active or temporarily disabled.
        :param pulumi.Input[dict] config: A configuration dictionary with keys and values depending on the jobs' type.
        :param pulumi.Input[float] frequency: The frequency, in seconds, at which to run the monitoring job in each region.
        :param pulumi.Input[str] job_type: The type of monitoring job to be run. See NS1 API
               docs for supported values.
        :param pulumi.Input[str] name: The free-form display name for the monitoring job.
        :param pulumi.Input[str] notes: Freeform notes to be included in any notifications about this job.
        :param pulumi.Input[float] notify_delay: The time in seconds after a failure to wait before sending a notification.
        :param pulumi.Input[bool] notify_failback: If true, a notification is sent when a job returns to an "up" state.
        :param pulumi.Input[str] notify_list: The id of the notification list to send notifications to.
        :param pulumi.Input[bool] notify_regional: If true, notifications are sent for any regional failure (and failback if desired), in addition to global state notifications.
        :param pulumi.Input[float] notify_repeat: The time in seconds between repeat notifications of a failed job.
        :param pulumi.Input[str] policy: The policy for determining the monitor's global status
               based on the status of the job in all regions. See NS1 API docs for supported values.
        :param pulumi.Input[bool] rapid_recheck: If true, on any apparent state change, the job is quickly re-run after one second to confirm the state change before notification.
        :param pulumi.Input[list] regions: The list of region codes in which to run the monitoring
               job. See NS1 API docs for supported values.
        :param pulumi.Input[list] rules: A list of rules for determining failure conditions. Job Rules are documented below.

        The **rules** object supports the following:

          * `comparison` (`pulumi.Input[str]`) - The comparison to perform on the the output.
          * `key` (`pulumi.Input[str]`) - The output key.
          * `value` (`pulumi.Input[str]`) - The value to compare to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["active"] = active
        __props__["config"] = config
        __props__["frequency"] = frequency
        __props__["job_type"] = job_type
        __props__["name"] = name
        __props__["notes"] = notes
        __props__["notify_delay"] = notify_delay
        __props__["notify_failback"] = notify_failback
        __props__["notify_list"] = notify_list
        __props__["notify_regional"] = notify_regional
        __props__["notify_repeat"] = notify_repeat
        __props__["policy"] = policy
        __props__["rapid_recheck"] = rapid_recheck
        __props__["regions"] = regions
        __props__["rules"] = rules
        return MonitoringJob(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class APIKey(pulumi.CustomResource):
    account_manage_account_settings: pulumi.Output[bool]
    """
    Whether the apikey can modify account settings.
    """
    account_manage_apikeys: pulumi.Output[bool]
    """
    Whether the apikey can modify account apikeys.
    """
    account_manage_payment_methods: pulumi.Output[bool]
    """
    Whether the apikey can modify account payment methods.
    """
    account_manage_plan: pulumi.Output[bool]
    """
    Whether the apikey can modify the account plan.
    """
    account_manage_teams: pulumi.Output[bool]
    """
    Whether the apikey can modify other teams in the account.
    """
    account_manage_users: pulumi.Output[bool]
    """
    Whether the apikey can modify account users.
    """
    account_view_activity_log: pulumi.Output[bool]
    """
    Whether the apikey can view activity logs.
    """
    account_view_invoices: pulumi.Output[bool]
    """
    Whether the apikey can view invoices.
    """
    data_manage_datafeeds: pulumi.Output[bool]
    """
    Whether the apikey can modify data feeds.
    """
    data_manage_datasources: pulumi.Output[bool]
    """
    Whether the apikey can modify data sources.
    """
    data_push_to_datafeeds: pulumi.Output[bool]
    """
    Whether the apikey can publish to data feeds.
    """
    dhcp_manage_dhcp: pulumi.Output[bool]
    """
    Whether the apikey can manage DHCP.
    Only relevant for the DDI product.
    """
    dhcp_view_dhcp: pulumi.Output[bool]
    """
    Whether the apikey can view DHCP.
    Only relevant for the DDI product.
    """
    dns_manage_zones: pulumi.Output[bool]
    """
    Whether the apikey can modify the accounts zones.
    """
    dns_view_zones: pulumi.Output[bool]
    """
    Whether the apikey can view the accounts zones.
    """
    dns_zones_allow_by_default: pulumi.Output[bool]
    """
    If true, enable the `dns_zones_allow` list, otherwise enable the `dns_zones_deny` list.
    """
    dns_zones_allows: pulumi.Output[list]
    """
    List of zones that the apikey may access.
    """
    dns_zones_denies: pulumi.Output[list]
    """
    List of zones that the apikey may not access.
    """
    ip_whitelist_strict: pulumi.Output[bool]
    """
    Sets exclusivity on this IP whitelist.
    """
    ip_whitelists: pulumi.Output[list]
    """
    The IP addresses to whitelist for this key.
    """
    ipam_manage_ipam: pulumi.Output[bool]
    """
    Whether the apikey can manage IPAM.
    Only relevant for the DDI product.
    """
    ipam_view_ipam: pulumi.Output[bool]
    """
    Whether the apikey can view IPAM.
    Only relevant for the DDI product.
    """
    key: pulumi.Output[str]
    """
    The apikeys authentication token.
    """
    monitoring_manage_jobs: pulumi.Output[bool]
    """
    Whether the apikey can modify monitoring jobs.
    """
    monitoring_manage_lists: pulumi.Output[bool]
    """
    Whether the apikey can modify notification lists.
    """
    monitoring_view_jobs: pulumi.Output[bool]
    """
    Whether the apikey can view monitoring jobs.
    """
    name: pulumi.Output[str]
    """
    The free form name of the apikey.
    """
    security_manage_active_directory: pulumi.Output[bool]
    """
    Whether the apikey can manage global active directory.
    Only relevant for the DDI product.
    """
    security_manage_global2fa: pulumi.Output[bool]
    """
    Whether the apikey can manage global two factor authentication.
    """
    teams: pulumi.Output[list]
    """
    The teams that the apikey belongs to.
    """
    def __init__(__self__, resource_name, opts=None, account_manage_account_settings=None, account_manage_apikeys=None, account_manage_payment_methods=None, account_manage_plan=None, account_manage_teams=None, account_manage_users=None, account_view_activity_log=None, account_view_invoices=None, data_manage_datafeeds=None, data_manage_datasources=None, data_push_to_datafeeds=None, dhcp_manage_dhcp=None, dhcp_view_dhcp=None, dns_manage_zones=None, dns_view_zones=None, dns_zones_allow_by_default=None, dns_zones_allows=None, dns_zones_denies=None, ip_whitelist_strict=None, ip_whitelists=None, ipam_manage_ipam=None, ipam_view_ipam=None, monitoring_manage_jobs=None, monitoring_manage_lists=None, monitoring_view_jobs=None, name=None, security_manage_active_directory=None, security_manage_global2fa=None, teams=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a APIKey resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] account_manage_account_settings: Whether the apikey can modify account settings.
        :param pulumi.Input[bool] account_manage_apikeys: Whether the apikey can modify account apikeys.
        :param pulumi.Input[bool] account_manage_payment_methods: Whether the apikey can modify account payment methods.
        :param pulumi.Input[bool] account_manage_plan: Whether the apikey can modify the account plan.
        :param pulumi.Input[bool] account_manage_teams: Whether the apikey can modify other teams in the account.
        :param pulumi.Input[bool] account_manage_users: Whether the apikey can modify account users.
        :param pulumi.Input[bool] account_view_activity_log: Whether the apikey can view activity logs.
        :param pulumi.Input[bool] account_view_invoices: Whether the apikey can view invoices.
        :param pulumi.Input[bool] data_manage_datafeeds: Whether the apikey can modify data feeds.
        :param pulumi.Input[bool] data_manage_datasources: Whether the apikey can modify data sources.
        :param pulumi.Input[bool] data_push_to_datafeeds: Whether the apikey can publish to data feeds.
        :param pulumi.Input[bool] dhcp_manage_dhcp: Whether the apikey can manage DHCP.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] dhcp_view_dhcp: Whether the apikey can view DHCP.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] dns_manage_zones: Whether the apikey can modify the accounts zones.
        :param pulumi.Input[bool] dns_view_zones: Whether the apikey can view the accounts zones.
        :param pulumi.Input[bool] dns_zones_allow_by_default: If true, enable the `dns_zones_allow` list, otherwise enable the `dns_zones_deny` list.
        :param pulumi.Input[list] dns_zones_allows: List of zones that the apikey may access.
        :param pulumi.Input[list] dns_zones_denies: List of zones that the apikey may not access.
        :param pulumi.Input[bool] ip_whitelist_strict: Sets exclusivity on this IP whitelist.
        :param pulumi.Input[list] ip_whitelists: The IP addresses to whitelist for this key.
        :param pulumi.Input[bool] ipam_manage_ipam: Whether the apikey can manage IPAM.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] ipam_view_ipam: Whether the apikey can view IPAM.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] monitoring_manage_jobs: Whether the apikey can modify monitoring jobs.
        :param pulumi.Input[bool] monitoring_manage_lists: Whether the apikey can modify notification lists.
        :param pulumi.Input[bool] monitoring_view_jobs: Whether the apikey can view monitoring jobs.
        :param pulumi.Input[str] name: The free form name of the apikey.
        :param pulumi.Input[bool] security_manage_active_directory: Whether the apikey can manage global active directory.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] security_manage_global2fa: Whether the apikey can manage global two factor authentication.
        :param pulumi.Input[list] teams: The teams that the apikey belongs to.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['account_manage_account_settings'] = account_manage_account_settings
            __props__['account_manage_apikeys'] = account_manage_apikeys
            __props__['account_manage_payment_methods'] = account_manage_payment_methods
            __props__['account_manage_plan'] = account_manage_plan
            __props__['account_manage_teams'] = account_manage_teams
            __props__['account_manage_users'] = account_manage_users
            __props__['account_view_activity_log'] = account_view_activity_log
            __props__['account_view_invoices'] = account_view_invoices
            __props__['data_manage_datafeeds'] = data_manage_datafeeds
            __props__['data_manage_datasources'] = data_manage_datasources
            __props__['data_push_to_datafeeds'] = data_push_to_datafeeds
            __props__['dhcp_manage_dhcp'] = dhcp_manage_dhcp
            __props__['dhcp_view_dhcp'] = dhcp_view_dhcp
            __props__['dns_manage_zones'] = dns_manage_zones
            __props__['dns_view_zones'] = dns_view_zones
            __props__['dns_zones_allow_by_default'] = dns_zones_allow_by_default
            __props__['dns_zones_allows'] = dns_zones_allows
            __props__['dns_zones_denies'] = dns_zones_denies
            __props__['ip_whitelist_strict'] = ip_whitelist_strict
            __props__['ip_whitelists'] = ip_whitelists
            __props__['ipam_manage_ipam'] = ipam_manage_ipam
            __props__['ipam_view_ipam'] = ipam_view_ipam
            __props__['monitoring_manage_jobs'] = monitoring_manage_jobs
            __props__['monitoring_manage_lists'] = monitoring_manage_lists
            __props__['monitoring_view_jobs'] = monitoring_view_jobs
            __props__['name'] = name
            __props__['security_manage_active_directory'] = security_manage_active_directory
            __props__['security_manage_global2fa'] = security_manage_global2fa
            __props__['teams'] = teams
            __props__['key'] = None
        super(APIKey, __self__).__init__(
            'ns1:index/aPIKey:APIKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, account_manage_account_settings=None, account_manage_apikeys=None, account_manage_payment_methods=None, account_manage_plan=None, account_manage_teams=None, account_manage_users=None, account_view_activity_log=None, account_view_invoices=None, data_manage_datafeeds=None, data_manage_datasources=None, data_push_to_datafeeds=None, dhcp_manage_dhcp=None, dhcp_view_dhcp=None, dns_manage_zones=None, dns_view_zones=None, dns_zones_allow_by_default=None, dns_zones_allows=None, dns_zones_denies=None, ip_whitelist_strict=None, ip_whitelists=None, ipam_manage_ipam=None, ipam_view_ipam=None, key=None, monitoring_manage_jobs=None, monitoring_manage_lists=None, monitoring_view_jobs=None, name=None, security_manage_active_directory=None, security_manage_global2fa=None, teams=None):
        """
        Get an existing APIKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] account_manage_account_settings: Whether the apikey can modify account settings.
        :param pulumi.Input[bool] account_manage_apikeys: Whether the apikey can modify account apikeys.
        :param pulumi.Input[bool] account_manage_payment_methods: Whether the apikey can modify account payment methods.
        :param pulumi.Input[bool] account_manage_plan: Whether the apikey can modify the account plan.
        :param pulumi.Input[bool] account_manage_teams: Whether the apikey can modify other teams in the account.
        :param pulumi.Input[bool] account_manage_users: Whether the apikey can modify account users.
        :param pulumi.Input[bool] account_view_activity_log: Whether the apikey can view activity logs.
        :param pulumi.Input[bool] account_view_invoices: Whether the apikey can view invoices.
        :param pulumi.Input[bool] data_manage_datafeeds: Whether the apikey can modify data feeds.
        :param pulumi.Input[bool] data_manage_datasources: Whether the apikey can modify data sources.
        :param pulumi.Input[bool] data_push_to_datafeeds: Whether the apikey can publish to data feeds.
        :param pulumi.Input[bool] dhcp_manage_dhcp: Whether the apikey can manage DHCP.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] dhcp_view_dhcp: Whether the apikey can view DHCP.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] dns_manage_zones: Whether the apikey can modify the accounts zones.
        :param pulumi.Input[bool] dns_view_zones: Whether the apikey can view the accounts zones.
        :param pulumi.Input[bool] dns_zones_allow_by_default: If true, enable the `dns_zones_allow` list, otherwise enable the `dns_zones_deny` list.
        :param pulumi.Input[list] dns_zones_allows: List of zones that the apikey may access.
        :param pulumi.Input[list] dns_zones_denies: List of zones that the apikey may not access.
        :param pulumi.Input[bool] ip_whitelist_strict: Sets exclusivity on this IP whitelist.
        :param pulumi.Input[list] ip_whitelists: The IP addresses to whitelist for this key.
        :param pulumi.Input[bool] ipam_manage_ipam: Whether the apikey can manage IPAM.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] ipam_view_ipam: Whether the apikey can view IPAM.
               Only relevant for the DDI product.
        :param pulumi.Input[str] key: The apikeys authentication token.
        :param pulumi.Input[bool] monitoring_manage_jobs: Whether the apikey can modify monitoring jobs.
        :param pulumi.Input[bool] monitoring_manage_lists: Whether the apikey can modify notification lists.
        :param pulumi.Input[bool] monitoring_view_jobs: Whether the apikey can view monitoring jobs.
        :param pulumi.Input[str] name: The free form name of the apikey.
        :param pulumi.Input[bool] security_manage_active_directory: Whether the apikey can manage global active directory.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] security_manage_global2fa: Whether the apikey can manage global two factor authentication.
        :param pulumi.Input[list] teams: The teams that the apikey belongs to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["account_manage_account_settings"] = account_manage_account_settings
        __props__["account_manage_apikeys"] = account_manage_apikeys
        __props__["account_manage_payment_methods"] = account_manage_payment_methods
        __props__["account_manage_plan"] = account_manage_plan
        __props__["account_manage_teams"] = account_manage_teams
        __props__["account_manage_users"] = account_manage_users
        __props__["account_view_activity_log"] = account_view_activity_log
        __props__["account_view_invoices"] = account_view_invoices
        __props__["data_manage_datafeeds"] = data_manage_datafeeds
        __props__["data_manage_datasources"] = data_manage_datasources
        __props__["data_push_to_datafeeds"] = data_push_to_datafeeds
        __props__["dhcp_manage_dhcp"] = dhcp_manage_dhcp
        __props__["dhcp_view_dhcp"] = dhcp_view_dhcp
        __props__["dns_manage_zones"] = dns_manage_zones
        __props__["dns_view_zones"] = dns_view_zones
        __props__["dns_zones_allow_by_default"] = dns_zones_allow_by_default
        __props__["dns_zones_allows"] = dns_zones_allows
        __props__["dns_zones_denies"] = dns_zones_denies
        __props__["ip_whitelist_strict"] = ip_whitelist_strict
        __props__["ip_whitelists"] = ip_whitelists
        __props__["ipam_manage_ipam"] = ipam_manage_ipam
        __props__["ipam_view_ipam"] = ipam_view_ipam
        __props__["key"] = key
        __props__["monitoring_manage_jobs"] = monitoring_manage_jobs
        __props__["monitoring_manage_lists"] = monitoring_manage_lists
        __props__["monitoring_view_jobs"] = monitoring_view_jobs
        __props__["name"] = name
        __props__["security_manage_active_directory"] = security_manage_active_directory
        __props__["security_manage_global2fa"] = security_manage_global2fa
        __props__["teams"] = teams
        return APIKey(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class DataFeed(pulumi.CustomResource):
    config: pulumi.Output[dict]
    """
    The feeds configuration matching the specification in
    `feed_config` from /data/sourcetypes.
    """
    name: pulumi.Output[str]
    """
    The free form name of the data feed.
    """
    source_id: pulumi.Output[str]
    """
    The data source id that this feed is connected to.
    """
    def __init__(__self__, resource_name, opts=None, config=None, name=None, source_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a NS1 Data Feed resource. This can be used to create, modify, and delete data feeds.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ns1 as ns1

        example = ns1.DataSource("example", sourcetype="nsone_v1")
        uswest_feed = ns1.DataFeed("uswestFeed",
            config={
                "label": "uswest",
            },
            source_id=example.id)
        useast_feed = ns1.DataFeed("useastFeed",
            config={
                "label": "useast",
            },
            source_id=example.id)
        ```
        ## NS1 Documentation

        [Datafeed Api Doc](https://ns1.com/api#data-feeds)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] config: The feeds configuration matching the specification in
               `feed_config` from /data/sourcetypes.
        :param pulumi.Input[str] name: The free form name of the data feed.
        :param pulumi.Input[str] source_id: The data source id that this feed is connected to.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['config'] = config
            __props__['name'] = name
            if source_id is None:
                raise TypeError("Missing required property 'source_id'")
            __props__['source_id'] = source_id
        super(DataFeed, __self__).__init__(
            'ns1:index/dataFeed:DataFeed',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, config=None, name=None, source_id=None):
        """
        Get an existing DataFeed resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] config: The feeds configuration matching the specification in
               `feed_config` from /data/sourcetypes.
        :param pulumi.Input[str] name: The free form name of the data feed.
        :param pulumi.Input[str] source_id: The data source id that this feed is connected to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["config"] = config
        __props__["name"] = name
        __props__["source_id"] = source_id
        return DataFeed(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop
